/***************************************************************************//**
 * @file
 * @brief RGB LED GATT Service header
 *******************************************************************************
 * # License
 * <b>Copyright 2020 Silicon Laboratories Inc. www.silabs.com</b>
 *******************************************************************************
 *
 * SPDX-License-Identifier: Zlib
 *
 * The licensor of this software is Silicon Laboratories Inc.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty. In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 *
 ******************************************************************************/

#ifndef SL_GATT_SERVICE_RGB_H
#define SL_GATT_SERVICE_RGB_H

/***********************************************************************************************//**
 * @addtogroup gatt_service_rgb
 * @{
 **************************************************************************************************/

#include "sl_bt_api.h"

/**************************************************************************//**
 * Bluetooth stack event handler.
 * @param[in] evt Event coming from the Bluetooth stack.
 *****************************************************************************/
void sl_gatt_service_rgb_on_event(sl_bt_msg_t* evt);

/**************************************************************************//**
 * Setter for RGB LEDs characteristic value.
 * @param[in] m LED bitmask.
 * @param[in] r Red intensity.
 * @param[in] g Green intensity.
 * @param[in] b Blue intensity.
 * @note To be implemented in user code.
 *****************************************************************************/
void sl_gatt_service_rgb_set_led(uint8_t m, uint8_t r, uint8_t g, uint8_t b);

/**************************************************************************//**
 * Returns a bitmask corresponding to the RGB LEDs the board has.
 * @return RGB LED mask.
 * @note To be implemented in user code.
 *****************************************************************************/
uint8_t sl_gatt_service_rgb_get_led_mask(void);

/** @} (end addtogroup gatt_service_rgb) */
#endif // SL_GATT_SERVICE_RGB_H
